Skip to contents

Returns information about the calibration models available in the leafwax package, including which covariates each model uses.

Usage

list_models(check_data = TRUE, verbose = TRUE)

Arguments

check_data

Logical, whether to check if model data is available

verbose

Logical, whether to print formatted output

Value

Data frame with model information

Examples

# \donttest{
# List all models
models <- list_models(verbose = FALSE)
models_head <- head(models)
# }