Loads or downloads the data manifest with file checksums. Returns NULL
with a warning when no current manifest is available. Download callers that
request verification fail closed in that case.
Loads or downloads the data manifest with file checksums. Returns NULL
with a warning when no current manifest is available. Download callers that
request verification fail closed in that case.