Returns information about the calibration models available in the leafwax package, including which covariates each model uses.
Examples
# \donttest{
# List all models
models <- list_models(verbose = FALSE)
models_head <- head(models)
# }
Returns information about the calibration models available in the leafwax package, including which covariates each model uses.
# \donttest{
# List all models
models <- list_models(verbose = FALSE)
models_head <- head(models)
# }